==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/uk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментарі",
    "Edit comment" : "Редагувати коментар",
    "Delete comment" : "Видалити коментар",
    "New comment …" : "Новий коментар...",
    "Post" : "Відправити",
    "Cancel" : "Скасувати",
    "[Deleted user]" : "[Видалений користувач]",
    "No comments yet, start the conversation!" : "Коментарі відсутні, почніть бесіду!",
    "More comments …" : "Більше коментарів ...",
    "Save" : "Зберегти",
    "Allowed characters {count} of {max}" : "Доступно символів {count} з {max}",
    "Error occurred while retrieving comment with ID {id}" : "Помилка під час відповіді на коментар ID {id}",
    "Error occurred while updating comment with id {id}" : "Помилка під час оновлення коментаря з id {id}",
    "Error occurred while posting comment" : "Помилка під час написання коментаря",
    "Comment" : "Коментар",
    "You commented" : "Ви прокоментували",
    "%1$s commented" : "%1$s прокоментовано",
    "{author} commented" : "{author} прокоментував",
    "You commented on %1$s" : "Ви прокоментували на %1$s",
    "You commented on {file}" : "Ви прокоментували {file}",
    "%1$s commented on %2$s" : "%1$s прокоментовано у %2$s",
    "{author} commented on {file}" : "{author} прокоментував {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментів</strong> для файлів",
    "Unknown user" : "Невідомий користувач"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/uk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментарі",
    "Edit comment" : "Редагувати коментар",
    "Delete comment" : "Видалити коментар",
    "New comment …" : "Новий коментар...",
    "Post" : "Відправити",
    "Cancel" : "Скасувати",
    "[Deleted user]" : "[Видалений користувач]",
    "No comments yet, start the conversation!" : "Коментарі відсутні, почніть бесіду!",
    "More comments …" : "Більше коментарів ...",
    "Save" : "Зберегти",
    "Allowed characters {count} of {max}" : "Доступно символів {count} з {max}",
    "Error occurred while retrieving comment with ID {id}" : "Помилка під час відповіді на коментар ID {id}",
    "Error occurred while updating comment with id {id}" : "Помилка під час оновлення коментаря з id {id}",
    "Error occurred while posting comment" : "Помилка під час написання коментаря",
    "Comment" : "Коментар",
    "You commented" : "Ви прокоментували",
    "%1$s commented" : "%1$s прокоментовано",
    "{author} commented" : "{author} прокоментував",
    "You commented on %1$s" : "Ви прокоментували на %1$s",
    "You commented on {file}" : "Ви прокоментували {file}",
    "%1$s commented on %2$s" : "%1$s прокоментовано у %2$s",
    "{author} commented on {file}" : "{author} прокоментував {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментів</strong> для файлів",
    "Unknown user" : "Невідомий користувач"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
